:mod:`kwant.plotter` -- Plotting of systems
===========================================

.. module:: kwant.plotter


Plotting routines
-----------------
.. autosummary::
   :toctree: generated/

   plot
   map
   density
   current
   bands
   spectrum
   streamplot
   scalarplot

Helper functions
----------------
.. autosummary::
   :toctree: generated/

   interpolate_current
   interpolate_density
   sys_leads_sites
   sys_leads_hoppings
   sys_leads_pos
   sys_leads_hopping_pos
   mask_interpolate
